from setuptools import setup

setup(name='haiderbhai_distributions',
      version='10.0',
      description='Binomial and Gaussian distributions',
      packages=['haiderbhai_distributions'],
      author = 'Syed Haider Ali Shah',
      author_email = '22110282@lums.edu.pk',
      zip_safe=False)
